mmd: rename dbinfo to selector_info
[paraslash.git] / afs.c
diff --git a/afs.c b/afs.c
index cb6c3882266876d240ddaaf1fb857d7cda75dbeb..a51db969f4853ea951549e9e5721e40aa397d5d0 100644 (file)
--- a/afs.c
+++ b/afs.c
@@ -18,8 +18,8 @@
 
 /** \file afs.c audio file sending functions
  *
 
 /** \file afs.c audio file sending functions
  *
* This contains the audio sending part of para_server which is independent
* of the current audio format, database tool and of the activated senders.
  */
 
 #include <sys/time.h> /* gettimeofday */
  */
 
 #include <sys/time.h> /* gettimeofday */
@@ -38,7 +38,7 @@ static struct timeval data_send_barrier;
 static struct timeval eof_barrier;
 
 extern struct misc_meta_data *mmd;
 static struct timeval eof_barrier;
 
 extern struct misc_meta_data *mmd;
-extern struct dbtool dblist[];
+extern struct audio_file_selector dblist[];
 extern struct sender senders[];
 extern struct gengetopt_args_info conf;
 
 extern struct sender senders[];
 extern struct gengetopt_args_info conf;
 
@@ -353,7 +353,7 @@ static void afs_eof(struct audio_format *af)
        free(tmp);
        tmp  = make_message("%s:\n%s:\n%s:\n", status_item_list[SI_DBINFO1],
                status_item_list[SI_DBINFO2], status_item_list[SI_DBINFO3]);
        free(tmp);
        tmp  = make_message("%s:\n%s:\n%s:\n", status_item_list[SI_DBINFO1],
                status_item_list[SI_DBINFO2], status_item_list[SI_DBINFO3]);
-       strcpy(mmd->dbinfo, tmp);
+       strcpy(mmd->selector_info, tmp);
        free(tmp);
        mmd->filename[0] = '\0';
        mmd->size = 0;
@@ -18,8 +18,8 @@
 /** \file afs.c audio file sending functions
  *
- * This contains the audio sending part of para_server which is independent
- * of the current audio format, database tool and of the activated senders.
+ * This contains the audio sending part of para_server which is independent of
+ * the current audio format, audio file selector and of the activated senders.
  */
 
        free(tmp);
        mmd->filename[0] = '\0';
        mmd->size = 0;